@@ -1035,7 +1035,7 @@ setMethod("asymptotic_term",signature(yuima="yuima"),
 	get_Y_e_V <- Y_e_V(X.t0,de.diffusion,env)
 
 	mu <- funcmu(env=env)
-	aMat <- funca(env=env)   ## ǥ顼 2010/11/24, TBC
+	aMat <- funca(env=env)   ## 2010/11/24, TBC
 	Sigma <- funcsigma(env=env)
 
 	invSigma <- solve(Sigma)
